#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

import logging
import PAR2Set.Base
import rsutil.common

#
# This is another base class for types that must
# run the extraction routine before the repair routine
#
# It will detect sets like the following:
# X.par2
# X.vol0+1.par2
# X.vol1+2.par2
# X.part01.rar
# X.part02.rar
# X.part03.rar
#
# Where the PAR2 files protect a file named X.avi, but not the X.part01.rar
# (and other) files.
#

class ExtractFirstBase (PAR2Set.Base.Base):

	def runAll (self):

		# Extraction Stage
		ret = self.runExtract ()

		if ret != rsutil.common.SUCCESS:
			logging.critical ('Extraction stage failed for: %s' % self.p2file)
			return -rsutil.common.EEXTRACT

		self.update_matches ()

		# Repair Stage
		ret = self.runVerifyAndRepair ()

		if ret != rsutil.common.SUCCESS:
			logging.critical ('Repair stage failed for: %s' % self.p2file)
			return -rsutil.common.ECHECK

		self.update_matches ()

		# Deletion Stage
		ret = self.runDelete ()

		if ret != rsutil.common.SUCCESS:
			logging.critical ('Deletion stage failed for: %s' % self.p2file)
			return -rsutil.common.EDELETE

		logging.info ('Successfully completed: %s' % self.p2file)
		return rsutil.common.SUCCESS

