#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

import PAR2Set.Base
import rsutil.common

#
# This is a regular zip file type
#
# It will detect sets like the following:
# X.par2
# X.vol0+1.par2
# X.vol1+2.par2
# X.zip
# ABC.zip
#
# Where the PAR2 files protect a file named X.zip and/or ABC.zip.
#

def detector (name_files, prot_files):
	all_files = rsutil.common.no_duplicates (name_files + prot_files)
	return rsutil.common.has_a_match ('^.*\.zip$', all_files)


class ZIP (PAR2Set.Base.Base):

	def __repr__ (self):
		return 'ZIP'

	def find_extraction_heads (self):
		return rsutil.common.find_matches ('^.*\.zip', self.all_files)

	def extraction_function (self, file, todir):
		ZIP_CMD = rsutil.common.config_get_value ('commands', 'unzip')

		cmd = ZIP_CMD % (file, todir)
		ret = rsutil.common.run_command (cmd)

		# Check error code
		if ret != 0:
			return -rsutil.common.EEXTRACT

		return rsutil.common.SUCCESS

